@@ -59,8 +59,12 @@ class WebSocketBroadcaster(object):
             data, addr = self.sock.recvfrom(65535)
             size = sys.getsizeof(data)
             print("Received {0} bytes of data from {1}.".format(size, addr))
-            for client in self.clients:
-                client.write_message(self.with_timestamp(data))
+            try:
+                client_message = self.with_timestamp(data)
+                for client in self.clients:
+                    client.write_message(self.with_timestamp(data))
+            except ValueError:
+                print("Invalid JSON message received: '{0}'".format(data))
 
     def with_timestamp(self, json_obj):
         """Returns a copy of a json obj with an additional time property."""
